@@ -4,6 +4,8 @@ from cast_arg.actionPlan import ActionPlan
 from cast_arg.config import Config
 from cast_arg.pages.greenIt import GreenIt
 from cast_arg.pages.summary import HighlightSummary
+from cast_arg.pages.benchmark import HighlightBenchmark
+
 from cast_arg.stats import OssStats,AIPStats,LicenseStats
 
 from cast_arg.pages.tech_detail_table import TechDetailTable
@@ -54,7 +56,8 @@ class GeneratePPT(Logger):
         super().__init__("generate",config.logging_generate)
         self._config = config
 
-        out = f"{config.output}/Project {config.project} - Tech DD Findings.pptx"
+        out = abspath(f"{config.output}/Project {config.project} - Tech DD Findings.pptx")
+        self.out=out
         self.info(f'Generating {out}')
 
         self._ppt = PowerPoint(config.template, out)
@@ -74,9 +77,14 @@ class GeneratePPT(Logger):
             self.info("Collecting Highlight Data")
             hl = Highlight(hl_base_url=config.hl_url,hl_user=config.hl_user,hl_pswd=config.hl_password, \
                            hl_instance=config.hl_instance,hl_apps=config.hl_list)
+            self.hl_portfolio_pages = [
+                HighlightSummary(self.day_rate)
+            ]
             self.hl_pages = [
                 HighlightSummary(self.day_rate),
-                GreenIt(self._config.output)
+                HighlightBenchmark(),
+                GreenIt(self._config.output),
+
             ]
             self._hl_data = HLData(config,log_level=config.logging_highlight)
 
@@ -107,7 +115,19 @@ class GeneratePPT(Logger):
                 self._ppt.delete_slide(idx)
 
     def save_ppt(self):
-        self._ppt.save()
+        while True:
+            try:
+                self._ppt.save()
+                self.info(f'{self.out} saved.')
+                return 
+            except PermissionError: 
+                while answer := input (f'Error writing {self.out} powerpoint document, Retry [Y or N]:'):
+                    if answer.upper() == 'Y':
+                        break
+                    elif answer.upper() == 'N':
+                        return
+                    else:
+                        continue
 
     def replace_all_text(self):
         app_cnt = len(self._config.application)
@@ -152,6 +172,12 @@ class GeneratePPT(Logger):
         lic_summary = LicenseStats(logger_level=self._config.logging_generate)
         summary_components = 0
 
+        """Highlight Portfolio level pages """
+        if self._config.hl_active:
+            for proc in self.hl_portfolio_pages:
+                proc.report(hl_list)
+
+
         self._ppt.replace_text('{app_cnt}',app_cnt)
         for idx in range(0,app_cnt):
             # create instance of action plan class 
